"""manual_0001_add_chore_tables

Revision ID: manual_0001
Revises: 8efbdc779a76
Create Date: 2025-05-21 08:00:00.000000

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision: str = 'manual_0001'
down_revision: Union[str, None] = '8efbdc779a76' # Last real migration
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None

# Enum definition for ChoreFrequencyEnum
chore_frequency_enum = sa.Enum('one_time', 'daily', 'weekly', 'monthly', 'custom', name='chorefrequencyenum')

def upgrade() -> None:
    """Upgrade schema."""
    # Create chorefrequencyenum type
    chore_frequency_enum.create(op.get_bind(), checkfirst=True)

    # Create chores table
    op.create_table('chores',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('group_id', sa.Integer(), nullable=False),
        sa.Column('name', sa.String(), nullable=False),
        sa.Column('description', sa.Text(), nullable=True),
        sa.Column('created_by_id', sa.Integer(), nullable=False),
        sa.Column('frequency', chore_frequency_enum, nullable=False),
        sa.Column('custom_interval_days', sa.Integer(), nullable=True),
        sa.Column('next_due_date', sa.Date(), nullable=False),
        sa.Column('last_completed_at', sa.DateTime(timezone=True), nullable=True),
        sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=False),
        sa.Column('updated_at', sa.DateTime(timezone=True), server_default=sa.text('now()'), onupdate=sa.text('now()'), nullable=False),
        sa.PrimaryKeyConstraint('id'),
        sa.ForeignKeyConstraint(['created_by_id'], ['users.id'], ),
        sa.ForeignKeyConstraint(['group_id'], ['groups.id'], ondelete='CASCADE'),
        sa.Index(op.f('ix_chores_created_by_id'), ['created_by_id'], unique=False),
        sa.Index(op.f('ix_chores_group_id'), ['group_id'], unique=False),
        sa.Index(op.f('ix_chores_id'), ['id'], unique=False),
        sa.Index(op.f('ix_chores_name'), ['name'], unique=False)
    )

    # Create chore_assignments table
    op.create_table('chore_assignments',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('chore_id', sa.Integer(), nullable=False),
        sa.Column('assigned_to_user_id', sa.Integer(), nullable=False),
        sa.Column('due_date', sa.Date(), nullable=False),
        sa.Column('is_complete', sa.Boolean(), server_default=sa.false(), nullable=False),
        sa.Column('completed_at', sa.DateTime(timezone=True), nullable=True),
        sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text('now()'), nullable=False),
        sa.Column('updated_at', sa.DateTime(timezone=True), server_default=sa.text('now()'), onupdate=sa.text('now()'), nullable=False),
        sa.PrimaryKeyConstraint('id'),
        sa.ForeignKeyConstraint(['assigned_to_user_id'], ['users.id'], ondelete='CASCADE'),
        sa.ForeignKeyConstraint(['chore_id'], ['chores.id'], ondelete='CASCADE'),
        sa.Index(op.f('ix_chore_assignments_assigned_to_user_id'), ['assigned_to_user_id'], unique=False),
        sa.Index(op.f('ix_chore_assignments_chore_id'), ['chore_id'], unique=False),
        sa.Index(op.f('ix_chore_assignments_id'), ['id'], unique=False)
    )

def downgrade() -> None:
    """Downgrade schema."""
    op.drop_table('chore_assignments')
    op.drop_table('chores')
    chore_frequency_enum.drop(op.get_bind(), checkfirst=True)
